@@ -1,13 +1,18 @@
 import pytest
+from fake_kubernetes_client import FakeDynamicClient
 from ocp_resources.model_registry_components_platform_opendatahub_io import ModelRegistry
 
 
 @pytest.mark.incremental
 class TestModelRegistry:
     @pytest.fixture(scope="class")
-    def modelregistry(self, fake_client):
+    def client(self):
+        return FakeDynamicClient()
+
+    @pytest.fixture(scope="class")
+    def modelregistry(self, client):
         return ModelRegistry(
-            client=fake_client,
+            client=client,
             name="test-modelregistry",
         )
 
