@@ -1,13 +1,18 @@
 import pytest
+from fake_kubernetes_client import FakeDynamicClient
 from ocp_resources.oauth import OAuth
 
 
 @pytest.mark.incremental
 class TestOAuth:
     @pytest.fixture(scope="class")
-    def oauth(self, fake_client):
+    def client(self):
+        return FakeDynamicClient()
+
+    @pytest.fixture(scope="class")
+    def oauth(self, client):
         return OAuth(
-            client=fake_client,
+            client=client,
             name="test-oauth",
         )
 
